/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Authors: Nicolas Dufresne <nicolas.dufresne@collabora.co.uk>
 */

#ifndef __TPL_CALL_EVENT_INTERNAL_H__
#define __TPL_CALL_EVENT_INTERNAL_H__

#include <telepathy-logger/call-event.h>
#include <telepathy-logger/event-internal.h>

G_BEGIN_DECLS

struct _TplCallEvent
{
  TplEvent parent;

  /* Private */
  TplCallEventPriv *priv;
};

struct _TplCallEventClass
{
  TplEventClass parent_class;
};

const gchar * _tpl_call_event_end_reason_to_str (TpCallStateChangeReason reason);
TpCallStateChangeReason _tpl_call_event_str_to_end_reason (const gchar *str);


G_END_DECLS
#endif // __TPL_CALL_EVENT_INTERNAL_H__
